@@ -12,7 +12,7 @@
 ##############################################################################
 """ Unit tests for ActionInformation module.
 
-$Id: test_ActionInformation.py 110577 2010-04-07 06:33:17Z jens $
+$Id: test_ActionInformation.py 112729 2010-05-26 15:08:55Z jens $
 """
 
 import unittest
@@ -107,7 +107,7 @@ class ActionTests(unittest.TestCase):
         request.set('manage_page_header', _header)
         request.set('manage_page_footer', _footer)
         request.set('BASEPATH1', '/one/two')
-        request.set('URL1', '/one/two')
+        setattr(request, 'URL1', '/one/two')
         request._steps = ['one', 'two']
 
         prd = {'ac_permissions': ('a', 'b')}
