@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -12,7 +12,7 @@
 ##############################################################################
 """ Unit tests for ActionProviderBase module.
 
-$Id: test_ActionProviderBase.py 100325 2009-05-24 09:10:10Z jens $
+$Id: test_ActionProviderBase.py 110577 2010-04-07 06:33:17Z jens $
 """
 
 import unittest
@@ -242,7 +242,7 @@ class ActionProviderBaseTests(SecurityRequestTest, WarningInterceptor):
     def test_listActionInfos(self):
         wanted = [{'id': 'an_id', 'title': 'A Title', 'description': '',
                    'url': '', 'category': 'object', 'visible': False,
-                   'available': True, 'allowed': True, 'link_target': '',
+                   'available': True, 'allowed': True, 'link_target': None,
                    'icon': ''}]
 
         apb = self.site._setObject( 'portal_apb', self._makeProvider(1) )
@@ -264,7 +264,7 @@ class ActionProviderBaseTests(SecurityRequestTest, WarningInterceptor):
     def test_getActionInfo(self):
         wanted = {'id': 'an_id', 'title': 'A Title', 'description': '',
                   'url': '', 'category': 'object', 'visible': False,
-                  'available': True, 'allowed': True, 'link_target': '',
+                  'available': True, 'allowed': True, 'link_target': None,
                   'icon': ''}
 
         apb = self.site._setObject( 'portal_apb', self._makeProvider(1) )
